@@ -2,9 +2,9 @@ package catbox
 
 import (
 	"fmt"
+	"github.com/Mikubill/transfer/apis"
+	"github.com/Mikubill/transfer/utils"
 	"github.com/spf13/cobra"
-	"transfer/apis"
-	"transfer/utils"
 )
 
 var (
