@@ -2,8 +2,9 @@ package chibi
 
 import (
 	"fmt"
-	"transfer/apis"
-	"transfer/utils"
+
+	"github.com/Mikubill/transfer/apis"
+	"github.com/Mikubill/transfer/utils"
 
 	"github.com/spf13/cobra"
 )
