@@ -2,9 +2,10 @@ package null
 
 import (
 	"fmt"
+	"github.com/Mikubill/transfer/apis"
+	"github.com/Mikubill/transfer/utils"
+
 	"github.com/spf13/cobra"
-	"transfer/apis"
-	"transfer/utils"
 )
 
 var (
@@ -18,7 +19,7 @@ type null struct {
 }
 
 func (b *null) SetArgs(cmd *cobra.Command) {
-	cmd.Long = fmt.Sprintf("vim-cn - https://0x0.st/\n\n" +
+	cmd.Long = fmt.Sprintf("null - https://0x0.st/\n\n" +
 		utils.Spacer("  Size Limit: 512M\n") +
 		utils.Spacer("  Upload Service: Cloudflare, Global\n") +
 		utils.Spacer("  Download Service: Cloudflare, Global\n"))
