@@ -2,9 +2,11 @@ package tmplink
 
 import (
 	"fmt"
+
+	"github.com/Mikubill/transfer/apis"
+	"github.com/Mikubill/transfer/utils"
+
 	"github.com/spf13/cobra"
-	"transfer/apis"
-	"transfer/utils"
 )
 
 var (
@@ -14,15 +16,14 @@ var (
 type tmpLink struct {
 	apis.Backend
 	resp     string
-	Config   wssOptions
+	Config   tmpOptions
 	Commands [][]string
 }
 
 func (b *tmpLink) SetArgs(cmd *cobra.Command) {
-	cmd.Flags().StringVarP(&b.Config.token, "token", "t", "", "Set your user token (required)")
+	cmd.Flags().StringVarP(&b.Config.token, "token", "t", "", "cli upload token. (leave blank for anonymous upload)")
 	cmd.Long = fmt.Sprintf("tmp.link - https://tmp.link/\n\n" +
-		utils.Spacer("  Size Limit: 1G(Anonymous), ~10G(Login)\n") +
+		utils.Spacer("  Size Limit: 50G(Anonymous), Unlimited(Login)\n") +
 		utils.Spacer("  Upload Service: multi-server, Global\n") +
-		utils.Spacer("  Download Service: multi-server, Global\n") +
-		"\n  Note: This backend only supports login users. (use -t to set token)\n")
+		utils.Spacer("  Download Service: multi-server, Global\n"))
 }
